@@ -14,7 +14,7 @@
 #  Repository:
 #  http://github.com/Skriptke/nes
 # 
-#  Version 1.01
+#  Version 1.02
 #
 #  Nes.pm
 #
@@ -26,7 +26,7 @@ use strict;
 # cgi environment no defined in command line
 no warnings 'uninitialized';
 
-our $VERSION          = '1.01';
+our $VERSION          = '1.02';
 our $CRLF             = "\015\012";
 our $MAX_INTERACTIONS = 500;
 our $MOD_PERL         = $ENV{'MOD_PERL'} || 0;
@@ -889,6 +889,7 @@ use Nes::Singleton;
 
     if ( open my $fh, '<', "$self->{'file_name'}" ) {
       @{ $self->{'file_souce'} } = <$fh>;
+      chomp $self->{'file_souce'}[$#{$self->{'file_souce'}}];
       close $fh;
     } else {
       warn "couldn't open $self->{'file_name'}";
@@ -934,8 +935,11 @@ use Nes::Singleton;
   sub set_out {
     my $self  = shift;
 
+    $self->{'file_nes_line'} = $self->{'file_souce'}[0] 
+      if $self->{'file_souce'}[0] =~ /{:\s*NES/i || '';
+       
     my $interpret = nes_interpret->new();
-    my @param     = $interpret->replace_NES( $self->{'file_souce'}[0] );
+    my @param     = $interpret->replace_NES( $self->{'file_nes_line'} );
 
     if ( $param[0] ) {
       shift @{ $self->{'file_souce'} };    # eliminamos la primera linea
@@ -1849,6 +1853,8 @@ use Nes::Singleton;
     my $self  = shift;
     my ($value, @security_options) = @_;
 
+    return $value if $value =~ /^\d*$/;
+
     my $tmp_no_html = $self->{'security_options'}{'no_html'};
     my $tmp_no_nes  = $self->{'security_options'}{'no_nes'};
     my $tmp_no_br   = $self->{'security_options'}{'no_br'};
@@ -1911,7 +1917,7 @@ use Nes::Singleton;
   sub replace_var {
     my $self  = shift;
     my ($var, @security_options) = @_;
- 
+
     return $self->security( $self->{'tags'}{$var}, @security_options );
   }
 
