@@ -1,3 +1,5 @@
+#!/usr/bin/perl
+
 # -----------------------------------------------------------------------------
 #
 #  Nes by Skriptke
@@ -13,31 +15,29 @@
 #  Repository:
 #  http://github.com/Skriptke/nes
 # 
-#  Version 1.04
+#  Version 1.00
 #
 #  Setting.pm
 #
 # -----------------------------------------------------------------------------
 
+{
+
   package Nes::Setting;
-  
-  use strict;
-  use warnings;    
 
   my $instance;
 
   sub new {
     my $class = shift;
-    my ( $ntop, $ndir ) = @_;
+          
+    utl::cleanup(\$instance) if $ENV{'MOD_PERL'};   
 
-    utl::cleanup(\$instance) if $ENV{'MOD_PERL'};
     return $instance if $instance;
 
     my $level       = utl::get_file_dir();
     my $file_name   = '.nes.cfg';
-    $ndir           = '/cgi-bin/nes' if $ntop && !$ndir;
-    my $nes_dir     = $ndir || $ENV{'SCRIPT_NAME'} || '/cgi-bin/nes';  # default: /cgi-bin/nes
-    my $nes_top_dir = $ntop || $ENV{'SCRIPT_FILENAME'} || ''; 
+    my $nes_dir     = $ENV{'SCRIPT_NAME'} || '/cgi-bin/nes';  # default: /cgi-bin/nes
+    my $nes_top_dir = $ENV{'SCRIPT_FILENAME'} || ''; 
     $nes_dir        =~ s/\/[^\/]*\.cgi|pl$//;
     $nes_top_dir    =~ s/\/[^\/]*\.cgi|pl$//;
 
@@ -46,7 +46,7 @@
 
     my $self = {
       tmp_dir        => '/tmp/nes',
-      tmp_suffix     => '.nes_tmp',
+      tmp_suffix     => '.nes_file_temp',
       tmp_clear      => 0, # borrar los archivos temporales de más del tiempo indicado, si es 0 no borra
       top_dir        => $top_dir,              # document root
       nes_top_dir    => $nes_top_dir,          # nes dir install
@@ -54,10 +54,7 @@
       plugin_dir     => $nes_dir . '/plugin',
       obj_dir        => $nes_dir . '/obj',
       plugin_top_dir => $nes_top_dir . '/plugin',
-      obj_top_dir    => $nes_top_dir . '/obj',     
-      obj_form       => $nes_top_dir . '/obj/Nes/form',
-      img_dir        => $nes_dir . '/images',
-      js_dir         => $nes_dir . '/js',
+      obj_top_dir    => $nes_top_dir . '/obj',      
       time_zone      => 'Europe/Madrid',       # * sin implementar *
       locale         => '',                    # es_ES.utf8
       session_prefix => 'NESSESSION',
@@ -112,9 +109,8 @@
         my $line = $_;
         next if $line =~ /^#/;
         next if $line =~ /^$/;
-        my ( $key, $value ) = split( /=\s*/, $line, 2 );
-        $key =~ s/\s*(\@|\%|\$)?$//;
-        my $eval = $1 || 0;
+        my ( $key, $value ) = split( /\s*=\s*/, $line, 2 );
+        my ( $eval ) = $key =~ s/[\@\%\$]$//;
         $value =~ s/\s*$//;
 
         # impide que se reescriba 'set';
@@ -129,9 +125,9 @@
             $eval = '@' if ref( $self->{$key} ) eq 'ARRAY';
             $eval = '%' if ref( $self->{$key} ) eq 'HASH';
             $eval = '$' if ref( $self->{$key} ) eq 'SCALAR';
-            @{ $self->{$key} } = eval   $value  if $eval eq '@';
+            @{ $self->{$key} } = eval { $value } if $eval eq '@';
             %{ $self->{$key} } = eval { $value } if $eval eq '%';
-            $self->{$key}      = eval  "$value"  if $eval eq '$';
+            $self->{$key}      = eval { $value } if $eval eq '$';
           } elsif ( ref( $self->{$key} ) eq 'ARRAY' ) {
             @{ $self->{$key} } = split( /,/, $value );
           } else {
@@ -151,9 +147,6 @@
     $self->{'obj_dir'}        =~ s/[\/\\]$//;
     $self->{'plugin_top_dir'} =~ s/[\/\\]$//;
     $self->{'obj_top_dir'}    =~ s/[\/\\]$//;
-    $self->{'obj_form'}       =~ s/[\/\\]$//;
-
-    push( @INC, ( $self->{'plugin_top_dir'}, $self->{'obj_top_dir'}, $self->{'obj_form'} )  );
     
     return;
   }
@@ -164,6 +157,7 @@
     return $self;
   }
 
+}
 
 1;
 
