@@ -1,26 +1,18 @@
 
-# -----------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
-#  Nes by Skriptke
+#  NES by - Skriptke
 #  Copyright 2009 - 2010 Enrique F. Castañón
 #  Licensed under the GNU GPL.
-#
-#  CPAN:
-#  http://search.cpan.org/dist/Nes/
-#
-#  Sample:
 #  http://nes.sourceforge.net/
-#
-#  Repository:
-#  http://github.com/Skriptke/nes
 # 
-#  Version 1.03
+#  Version 0.9 pre
 #
 #  forms_plugin.pm
 #
-# -----------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
-# despues de tanto parche, esto hay que volver a escribirlo.
 package forms_plugin;
 
 use strict;
@@ -40,10 +32,6 @@ use strict;
     $self->{'captcha_name'} = '';
 
     $self->{'tag_form'} = 'form';
-    
-    foreach my $tag ( keys %{ $self->{'container'}->{'content_obj'}->{'tags'} } ) {
-      $self->{'tags'}{$tag} = $self->{'container'}->{'content_obj'}->{'tags'}{$tag};
-    }    
 
     return $self;
   }
@@ -74,15 +62,23 @@ use strict;
     my $self = shift;
     my ( $code, @param ) = @_;
 
+    foreach (@param) {
+
+      # sólo los que tengan código, ahorrar un poco de cpu
+      if (/$self->{'pre_start'}/) {
+        my $interpret = nes_interpret->new( $self->postformat($_) );
+        $_ = $interpret->go( %{ $self->{'tags'} } );
+      }
+    }
+
     $self->{'name'} = shift @param;
     $self->{'auto_submit'} = 1 if $self->{'auto_submit'} ne '0';
 
     $self->{'form'}{ $self->{'name'} } = nes_forms->new( $code, $self->{'name'}, @param );
-    $self->{'form'}{ $self->{'name'} }->replace_form();
 
     return $self->{'form'}{ $self->{'name'} }->out();
   }
-  
+
 }
 
 {
@@ -93,26 +89,11 @@ use strict;
 
   sub new {
     my $class = shift;
-    my ( $out, $name, $auto_submit, $captcha_name, $captcha_last, $expire, $expire_last, $location, $attempts, $attempts_for_captcha ) = @_;
+    my ( $out, $name, $auto_submit, $captcha_name, $captcha_last, $expire, $expire_last, $location, $attempts ) = @_;
     my $self = $class->SUPER::new();
 
-    foreach my $tag ( keys %{ $self->{'container'}->{'content_obj'}->{'tags'} } ) {
-      $self->{'tags'}{$tag} = $self->{'container'}->{'content_obj'}->{'tags'}{$tag};
-    }    
-
-#    $self->{'plugin'} = nes_plugin->get_obj('forms_plugin');
-#    $self->{'plugin'}->add_obj( $name, $self );
-    
-    
     $self->{'plugin'} = nes_plugin->get_obj('forms_plugin');
-    if ($self->{'plugin'} =~ /nes_plugin/) {
-      # antiguo método, obsoleto
-      $self->{'plugin'}->add_obj( $name, $self );
-    }
-    # nevo método
-    $self->{'plugin'} = $self->{'register'}->add_obj('forms_plugin', $name, $self);    
-    
-    $self->{'attempts_for_captcha'} = $attempts_for_captcha;
+    $self->{'plugin'}->add_obj( $name, $self );
 
     $self->{'tag_obfuscated'} = 'obfuscated';
     $self->{'tag_form_check'} = 'check';
@@ -136,7 +117,7 @@ use strict;
     $self->{'form_start_field'}  = '<input type="hidden" name="' . $self->{'form_start_name'} . '"  value="' . $self->{'name'} . '" />';
     $self->{'form_finish_field'} = '<input type="hidden" name="' . $self->{'form_finish_name'} . '"  value="' . $self->{'name'} . '" />';
     $self->{'auto_submit_field'} = '';
-    $self->{'auto_submit_field'} = 'document.' . $self->{'name'} . '.submit();';
+    $self->{'auto_submit_field'} = 'document.' . $self->{'name'} . '.submit();' if $self->{'auto_submit'};
 
     $self->{'tmp'} = nes_tmp->new( $self->{'CFG'}{'forms_plugin_suffix'}, $self->{'name'} );
 
@@ -145,12 +126,12 @@ use strict;
     $self->{'form_is_finish'} = 0;
     $self->{'form_is_finish'} = 1 if $self->{'form_finish'} eq $self->{'name'};
 
-    $self->{'expire'}      = $expire      || $self->{'CFG'}{'forms_plugin_expire'};
-    $self->{'expire_last'} = $expire_last || $self->{'CFG'}{'forms_plugin_expire_last'};
+    $self->{'expire'} = $expire || $self->{'CFG'}{'forms_plugin_expire'};
+    $self->{'expire'} = $expire_last || $self->{'CFG'}{'forms_plugin_expire_last'} if $self->{'form_is_start'};
 
     $self->{'is_ok'} = 0;
 
-#    $self->replace_form();
+    $self->replace_form();
 
     return $self;
   }
@@ -160,17 +141,11 @@ use strict;
 
     if ( $self->{'form_is_start'} ) {
       $self->load();
-      $self->{'tmp'}->save( time . ':' ) if !$self->{'form_is_finish'};
+      $self->{'tmp'}->save( time . ':' );
     }
     
     $self->get_attempts;
-
-    if ( $self->{'attempts'} < $self->{'attempts_for_captcha'}+1 && $self->{'attempts_for_captcha'} ) {
-      $self->{'auto_submit'}  = 1;
-      $self->{'captcha_name'} = '';
-      $self->{'captcha_last'} = '';
-    }    
-
+    
     $self->replace_check();
     $self->replace_obfuscated();
     $self->replace_init_form();
@@ -258,11 +233,10 @@ use strict;
         }
 
       }
-      if ( $type =~ /^\/(.*)\/(.*)$/ ) {
-        my $regex = "(?x$2)$1";
+      if ( $type =~ /^\/(.*)\/$/ ) {
 
         if ($this_field) {    # sólo da error si el campo no esta vacío, podía ser opcional
-          $error .= 'regular expression' if $this_field !~ /$regex/;
+          $error .= 'regular expression' if $this_field !~ /$1/;
         }
 
       }
@@ -278,38 +252,17 @@ use strict;
 
   sub replace_obfuscated {
     my $self = shift;
-    
-#    $self->{'out'} =~ s/$self->{'pre_start'}\s*$self->{'tag_plugin'}\s*$self->{'tag_obfuscated'}\s*(.+?)\s*$self->{'pre_end'}/$self->{'obfuscated'}{$1} = $self->get_key( 5 + int rand 4 )/egi;
-#    return;
-    
-    my $obfuscated_tag = qr{(?six)
-                        \s*$self->{'pre_start'}\s*
-                            $self->{'tag_plugin'}
-                            \s*
-                            $self->{'tag_obfuscated'}    # tag del plugin
-                            \s*
-                            (\([^\(\)]+\)|[^\(\)]\S+)    # parametros
-                            \s*
-                        $self->{'pre_end'}\s*
-                        };  
-    
-    $self->{'out'} =~ s/$obfuscated_tag/$self->obfuscated($self->param_block($1))/ge;     
-   
+
+    $self->{'out'} =~ s/$self->{'pre_start'}\s*$self->{'tag_plugin'}\s*$self->{'tag_obfuscated'}\s*(.+?)\s*$self->{'pre_end'}/$self->{'obfuscated'}{$1} = $self->get_key( 5 + int rand 4 )/egi;
+
     return;
   }
-  
-  sub obfuscated {
-    my $self = shift;
-    my ( $field ) = @_;
 
-    return $self->{'obfuscated'}{$field} = $self->get_key( 5 + int rand 4 );
-  }  
-  
   sub replace_init_form {
     my $self = shift;
 
     # siempre, indica que se ha iniciado el formulario
-    $self->{'out'} =~ s/(\<\/form\>)/$self->{'form_start_field'}$1/;
+    $self->{'out'} =~ s/(\<\/form\>)/$self->{'form_start_field'}\n$1/;
 
     return;
   }
@@ -337,14 +290,11 @@ use strict;
       $self->{'out'} =~ s/<select /<input readonly=\"readonly\" /gi;
 
       # excluimos submit y captcha
-      $self->{'out'} =~ s/<input readonly=\"readonly\" (.*type\s*=\s*\"?hidden\"?)/<input $1/gi;
       $self->{'out'} =~ s/<input readonly=\"readonly\" (.*type\s*=\s*\"?submit\"?)/<input $1/gi;
       $self->{'out'} =~ s/<input readonly=\"readonly\" (.*name\s*=\s*\"?$self->{'CFG'}{'captcha_plugin_start'}_$self->{'captcha_name'}\"?)/<input $1/gi if $self->{'captcha_name'};
       $self->{'out'} =~ s/<input readonly=\"readonly\" (.*name\s*=\s*\"?$self->{'captcha_name'}\"?)/<input $1/gi if $self->{'captcha_name'};
-      $self->{'out'} =~ s/<input readonly=\"readonly\" (.*this_is_captcha_field)/<input $1/gi;
     }
 
-    $self->{'auto_submit_field'} = ''  if !$self->{'auto_submit'};
     if ( $self->{'form_is_start'} && !$self->{'form_is_finish'} ) {
       $self->{'last_step'} = 1;
       $self->{'plugin'}->add_env( 'forms_plugin', $self->{'name'}, 'last_step', '1' );
@@ -356,7 +306,6 @@ use strict;
       $js_code =
         '<script>' . $js_var . ' = unescape(\'' . utl::escape($js_code) . '\');document.write(' . $js_var . ');' . $self->{'auto_submit_field'} . '</script>';
       $self->{'out'} =~ s/(\<\/form\>)/$self->{'form_finish_field'}$js_code\n$1/;
-      $self->{'expired'} = ( ( $self->{'time_cookie'} + utl::expires_time( $self->{'expire_last'} ) ) < time );
     }
 
     return;
@@ -388,6 +337,13 @@ use strict;
     $self->{'plugin'}->add_last_error( 'forms_plugin', $self->{'name'}, "max attempts, wait $self->{'max_time'} minutes" );
     return 0 if $self->{'attempts'} > $self->{'max_attempts'};
 
+    # no se ha terminado de llenar el formulario
+    $self->{'last_error'} = 'no form finish';
+    $self->{'fatal_error'} = 0;
+    $self->{'plugin'}->add_last_error( 'forms_plugin', $self->{'name'}, 'no form finish' );
+    $self->{'plugin'}->add_fatal_error( 'forms_plugin', $self->{'name'}, '' );
+    return 0 if !$self->{'form_is_finish'};
+
     # no existe la cookie
     $self->{'last_error'}  = 'no cookie';
     $self->{'fatal_error'} = 1;
@@ -402,13 +358,6 @@ use strict;
     $self->{'plugin'}->add_last_error( 'forms_plugin', $self->{'name'}, 'cookie expired, posible manipulate cookie' );
     return 0 if $self->{'expired'};
 
-    # no se ha terminado de llenar el formulario
-    $self->{'last_error'} = 'no form finish';
-    $self->{'fatal_error'} = 0;
-    $self->{'plugin'}->add_last_error( 'forms_plugin', $self->{'name'}, 'no form finish' );
-    $self->{'plugin'}->add_fatal_error( 'forms_plugin', $self->{'name'}, '' );
-    return 0 if !$self->{'form_is_finish'};
-
     # hash no coninciden, seguramente la cookie ha sido manipulada
     $self->{'last_error'}  = 'posible manipulate cookie data';
     $self->{'fatal_error'} = 3;
@@ -441,8 +390,8 @@ use strict;
     $self->{'fatal_error'} = 0;
     $self->{'plugin'}->add_fatal_error( 'forms_plugin', $self->{'name'}, 0 );
     $self->{'plugin'}->add_last_error( 'forms_plugin', $self->{'name'}, 'ok' );
-#    my $data = time . ':' . $self->{'key_value'};
-#    $self->{'tmp'}->clear($data);
+    my $data = time . ':' . $self->{'key_value'};
+    $self->{'tmp'}->clear($data);
 
     $self->{'is_ok'} = 1;
 
@@ -512,11 +461,7 @@ use strict;
     }
     $self->{'generated_hash'} = md5_hex($pass);
     $self->{'load_hash'}      = $hash;
-    $self->{'time_cookie'}    = $time;
-    $self->{'expired'} = ( ( $self->{'time_cookie'} + utl::expires_time( $self->{'expire'} ) ) < time );
-
-#$self->{'plugin'}->add_env( 'forms_plugin', 'pp', 'expired', $self->{'expire'} );
-#    $self->{'expired'}        = ( ( $time + utl::expires_time( $self->{'expire'} ) ) < time );
+    $self->{'expired'}        = ( ( $time + utl::expires_time( $self->{'expire'} ) ) < time );
 
     foreach my $key ( keys %obfuscated ) {
       my $key_value = $self->{'query'}->get($key);
